@@ -345,8 +345,8 @@ void HistoryView::loadInitial(bool reload) {
 		}
 	}
 	if(settings->v_expression.empty()) {
-		if(!settings->clear_history_on_exit && !reload && !b_reversed) {
-			setHtml("<body color=\"" + text_color.name() + "\">" + tr("Type a mathematical expression above, e.g. \"5 + 2 / 3\", and press the enter key.") + "</body>");
+		if(!settings->clear_history_on_exit && !reload) {
+			setHtml("<body color=\"" + text_color.name() + "\">" + (b_reversed ? tr("Type a mathematical expression below, e.g. \"5 + 2 / 3\", and press the enter key.") : tr("Type a mathematical expression above, e.g. \"5 + 2 / 3\", and press the enter key.")) + "</body>");
 		} else {
 			setHtml("<body color=\"" + text_color.name() + "\"></body>");
 		}
@@ -885,9 +885,11 @@ void HistoryView::addMessages() {
 void HistoryView::mouseMoveEvent(QMouseEvent *e) {
 	QString str = anchorAt(e->pos());
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
+	QPoint p = e->pos();
+	p.ry() += verticalScrollBar()->value();
 	bool b_tooltip = false;
-	if(str.isEmpty() && (document()->documentLayout()->imageAt(e->pos()).indexOf(":/icons") == 0 || (e->pos().x() > width() - 150 && document()->documentLayout()->imageAt(e->pos()).indexOf(":/data/flags") == 0))) {
-		QPoint p(viewport()->mapFromParent(e->pos()));
+	if(str.isEmpty() && (document()->documentLayout()->imageAt(p).indexOf(":/icons") == 0 || (e->pos().x() > width() - 150 && document()->documentLayout()->imageAt(p).indexOf(":/data/flags") == 0))) {
+		p = viewport()->mapFromParent(e->pos());
 		for(int n = 0; n < 5; n++) {
 			QTextCursor cur = cursorForPosition(p);
 			cur.movePosition(QTextCursor::StartOfBlock, QTextCursor::KeepAnchor);
@@ -901,7 +903,7 @@ void HistoryView::mouseMoveEvent(QMouseEvent *e) {
 					if(str == "temporary_error") str = temporary_error;
 					else str.replace("\\n", "\n");
 					if(!str.isEmpty()) {
-						QToolTip::showText(mapToGlobal(e->pos()), str);
+						QToolTip::showText(mapToGlobal(e->pos()), str, this);
 						b_tooltip = true;
 					}
 				}
