@@ -127,7 +127,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	BOX(tr("Close application with Escape key"), settings->close_with_esc, closeWithEscToggled(bool));
 	BOX(tr("Use keyboard keys for RPN"), settings->rpn_keys && settings->evalops.parse_options.parsing_mode != PARSING_MODE_RPN, rpnKeysToggled(bool)); rpnKeysBox = box; rpnKeysBox->setEnabled(settings->evalops.parse_options.parsing_mode != PARSING_MODE_RPN);
 	BOX(tr("Use caret for bitwise XOR"), settings->caret_as_xor, caretAsXorToggled(bool));
-	BOX(tr("Keep above other windows"), settings->always_on_top, keepAboveToggled(bool));
+	BOX(tr("Keep above other windows"), settings->always_on_top, keepAboveToggled(bool)); if(settings->wayland_platform) box->hide();
 	QCheckBox *box2 = new QCheckBox(tr("Preserve history height"), this); l->addWidget(box2, r, 0, 1, 2); connect(box2, SIGNAL(stateChanged(int)), this, SLOT(preserveHeightChanged(int))); r++;
 	preserveHeightBox = box2;
 	if(settings->preserve_history_height < 0) {
@@ -137,7 +137,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 		box2->setChecked(settings->preserve_history_height > 0);
 	}
 	box2->setToolTip(tr("Do not change the height of history list when keypad or number bases are show or hidden."));
-	BOX(tr("Place expression field below history"), settings->expression_pos == 1, expressionPositionToggled(bool));
+	BOX(tr("Place expression field below history"), settings->expression_pos != 0, expressionPositionToggled(bool));
 	BOX(tr("Show status bar"), settings->show_statusbar || settings->status_in_statusbar, showStatusBarToggled(bool));
 	l->addWidget(new QLabel(tr("Window title:"), this), r, 0);
 	combo = new QComboBox(this);
@@ -694,12 +694,18 @@ void PreferencesDialog::decimalCommaToggled(bool b) {
 void PreferencesDialog::ignoreDotToggled(bool b) {
 	settings->evalops.parse_options.dot_as_separator = b;
 	settings->dot_question_asked = true;
+	if(settings->automatic_digit_grouping && settings->printops.digit_grouping == DIGIT_GROUPING_LOCALE && CALCULATOR->local_digit_group_separator == DOT) {
+		emit automaticDigitGroupingChanged();
+	}
 	emit expressionFormatUpdated(false);
 }
 void PreferencesDialog::ignoreCommaToggled(bool b) {
 	settings->evalops.parse_options.comma_as_separator = b;
 	CALCULATOR->useDecimalPoint(settings->evalops.parse_options.comma_as_separator);
 	settings->dot_question_asked = true;
+	if(settings->automatic_digit_grouping && settings->printops.digit_grouping == DIGIT_GROUPING_LOCALE && CALCULATOR->local_digit_group_separator == COMMA) {
+		emit automaticDigitGroupingChanged();
+	}
 	emit expressionFormatUpdated(false);
 	emit symbolsUpdated();
 }
@@ -925,6 +931,7 @@ void PreferencesDialog::groupingChanged(int i) {
 	} else {
 		emit resultFormatUpdated();
 	}
+	if(settings->automatic_digit_grouping) emit automaticDigitGroupingChanged();
 }
 void PreferencesDialog::cgfChanged(int i) {
 	if(!settings->custom_digit_grouping) return;
@@ -935,6 +942,7 @@ void PreferencesDialog::cgfChanged(int i) {
 	}
 	settings->custom_digit_group_changed = true;
 	emit resultFormatUpdated();
+	if(settings->automatic_digit_grouping) emit automaticDigitGroupingChanged();
 }
 void PreferencesDialog::cgsChanged(const QString &str) {
 	if(!settings->custom_digit_grouping) return;
@@ -942,6 +950,7 @@ void PreferencesDialog::cgsChanged(const QString &str) {
 	CALCULATOR->local_digit_group_separator = settings->custom_digit_group_separator;
 	settings->custom_digit_group_changed = true;
 	emit resultFormatUpdated();
+	if(settings->automatic_digit_grouping) emit automaticDigitGroupingChanged();
 }
 void PreferencesDialog::intervalDisplayChanged(int i) {
 	if(i == 0) {
